@@ -804,11 +804,6 @@ void CDraftFrame::OnDestroy()
 	// save window position in ini file.
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 
-	int max = m_me.HowManyPart();
-	for(int i=1; i<max; i++){
-		DeleteFile(m_me.GetMultipartFileName(i));
-	}
-	
 	app->WriteProfileInt("DraftWndPlace", "Left", wndPlace.rcNormalPosition.left);
 	app->WriteProfileInt("DraftWndPlace", "Top", wndPlace.rcNormalPosition.top);
 	app->WriteProfileInt("DraftWndPlace", "Right", wndPlace.rcNormalPosition.right);
