@@ -198,9 +198,10 @@ void CMailEditView::OnInitialUpdate()
 	// {ݒ
 	CDraftFrame* df = (CDraftFrame*)GetParentFrame();
 	CString body;
+	
 	if(df->m_me.GetMode() == ME_MODE_PGP){
 		body = df->m_me.GetMultipartBody(1);
-		r.SetReadOnly();
+		r.SetReadOnly(TRUE);
 	}else{
 		body = df->m_me.GetMultipartBody(0);
 	}
@@ -760,9 +761,11 @@ void CMailEditView::SetFontColorAndLink()
 void CMailEditView::OnDropFiles(HDROP hDropInfo) 
 {
 //	CRichEditView::OnDropFiles(hDropInfo);
-
-	this->GetRichEditCtrl().UpdateData(TRUE);
 	CDraftFrame *df = (CDraftFrame*)GetParentFrame();
+	if (df->m_me.GetMode()==ME_MODE_PGP)
+		return;
+	this->GetRichEditCtrl().UpdateData(TRUE);
+	
 
 	// count number of droped file
 	int num = DragQueryFile(hDropInfo,~0lu, NULL, 0);
