@@ -520,6 +520,7 @@ void CMainFrame::OnGpgDec()
 	header.TrimRight();
 	header += "\r\n";
 	m_pTextV->Update2(header+"\r\n"+body);
+	this->UpdateButton2(TRUE);
 }
 
 void CMainFrame::OnUpdateGpgDec(CCmdUI* pCmdUI)
@@ -1129,8 +1130,11 @@ void CMainFrame::UpdateButton1(BOOL b, CString account)
 
 void CMainFrame::UpdateButton2(BOOL b)
 {
-	// each button(reply, transfer, header info) is invalidate
-	m_button_reply = b;
+	if (m_pTextV->IsPgpMime()) {
+		m_button_reply = FALSE;	
+	}else{// each button(reply, transfer, header info) is invalidate
+		m_button_reply = b;	
+	}
 	m_button_transfer = b;
 	m_button_info = b;
 }
@@ -1322,10 +1326,13 @@ void CMainFrame::OnTransferQuotation()
 	tmpl.SetAddress(address);
 
 	// setting mail body
-
-	app->m_me.AddText(tmpl.GetString(&(m_pTextV->m_md), body_tmpl));
+	if (!m_pTextV->m_md.IsPgpMime()) {
+		app->m_me.AddText(tmpl.GetString(&(m_pTextV->m_md), body_tmpl));
+	}else{
+		app->m_me.SetMode(m_pTextV->m_md.IsPgpMime());
+	}
 	
-	partCnt = m_pTextV->m_md.HowManyPart();	
+	partCnt = m_pTextV->m_md.HowManyPart();
 	int mainPart = m_pTextV->m_md.GetMainTextPartNo();
 // 2005.11.29 moogv mod start
 //	for (i=1;i<partCnt;++i) {
@@ -1341,8 +1348,13 @@ void CMainFrame::OnTransferQuotation()
 		data.m_file_name = m_pTextV->m_md.GetFileName(i);
 //2005.11.29 moogv add
 		//data.m_content_type = m_pTextV->m_md.GetContentType(i);	
-		data.m_content_type.Format("Content-Type: %s; name=\"%s\"", 
-			m_pTextV->m_md.GetContentType(i), data.m_file_name);
+		if (m_pTextV->m_md.IsPgpMime()) {
+			data.m_content_type.Format("Content-Type: %s", 
+				m_pTextV->m_md.GetContentType(i));
+		}else{
+			data.m_content_type.Format("Content-Type: %s; name=\"%s\"", 
+				m_pTextV->m_md.GetContentType(i), data.m_file_name);
+		}
 //2005.11.29 moogv end
 		data.m_content_transfer_encoding=m_pTextV->m_md.GetRawCTE(i);
 		data.m_content_disposition = m_pTextV->m_md.GetRawCD(i);
