@@ -229,7 +229,7 @@ BOOL CMimeDecode::DoIt(CString path)
 		int max = m_data.GetSize();
 		for(n=0; n<max; n++){
 			if(!m_data.GetAt(n).boundary.IsEmpty())
-				if(!AnalyzeMultiPart(m_data.GetAt(n).start, m_data.GetAt(n).boundary)){
+				if(!AnalyzeMultiPart(m_data.GetAt(n).start, m_data.GetAt(n).boundary)){					
 					AfxMessageBox("MIME̍\ςł");
 					return FALSE;
 				}
@@ -442,4 +442,19 @@ CString CMimeDecode::GetExtension(CString media_type)
 	CString extension;
 	map.Lookup(media_type, extension);
 	return extension;
-}
\ No newline at end of file
+}
+
+
+int CMimeDecode::GetMainTextPartNo()
+{
+	int max = HowManyPart();
+	for (int i = 0;i < max; ++i) {
+		CString type = GetContentType(i);
+		type.MakeUpper();		
+		int no = type.Find("TEXT",0);
+		if (no >= 0) 
+			return (i);
+	}	
+	return (-1);
+}
+
