@@ -12,10 +12,12 @@
 #include "MimeEncode.h"
 #include "base64.h"
 #include "CodeConvert.h"
+#include "quoted-printable.h" //add 2005/12/05
 #include "lib.h"
 #include "process.h" // getpid()
 #include "_regex.h"
-
+#include "direct.h" //_mkdir()
+#include "HeaderInfo.h"
 #ifdef _DEBUG
 #undef THIS_FILE
 static char THIS_FILE[]=__FILE__;
@@ -435,6 +437,7 @@ BOOL CMimeEncode::EncodeBase64FromFile(CString path, CString &buf)
 	return TRUE;
 }
 
+
 BOOL CMimeEncode::AddAttachedFile(CString path)
 {
 /*	Content-Type: application/octet-stream; name=hogehoge
@@ -1103,3 +1106,49 @@ void CMimeEncode::EncodeParam(CString buf, CStringArray &array)
 	last1:
 	regfree(&reg1);
 }
+
+BOOL CMimeEncode::SetAttachedFileToTemp(int partNo, CString outDir, CString &path)
+{
+	if (partNo <= 0) return (false);
+	
+	CString body = GetMultipartBody(partNo);
+
+	outDir.TrimRight();
+	if (outDir.Find("\\",outDir.GetLength()-1) >= 0)
+		outDir.Mid(0,outDir.GetLength()-1);
+
+	if(!g_is_there(outDir)) // if no tmp folder, create.
+		_mkdir(outDir);	
+
+	//path = outDir+"\\"+GetMultipartFileName(partNo);
+	path = g_get_app_tmp_file(outDir,g_get_file_extension(GetMultipartFileName(partNo)));
+	FILE* file = fopen(path, "wb");
+	// base64
+	if (g_string_compare_no_case(GetMultipartEncType(partNo),"BASE64")) {
+		body.Remove('\r');
+		body.Remove('\n');
+		char* out = new char[body.GetLength()];
+		int len = from64tobits(out, body, body.GetLength());
+		fwrite(out, sizeof(char), len, file);
+		fclose(file);
+		delete[] out;
+		body.ReleaseBuffer();
+	} else if(g_string_compare_no_case(GetMultipartEncType(partNo),"quoted-printable")){ // quoted-pritable
+		char* out = new char[body.GetLength()+10];
+		int len = fromQPtobits(out, body, body.GetLength());
+		fwrite(out, sizeof(char), len, file);
+		fclose(file);
+		delete[] out;
+		body.ReleaseBuffer();
+	} else {
+		if(g_string_compare_no_case(GetMultipartEncType(partNo),"7bit") || g_string_compare_no_case(GetMultipartEncType(partNo),"8bit")){
+			CCodeConvert cc;
+			cc.SetString(body);
+			body = cc.ToSjis();
+		}
+		fwrite(body, sizeof(char), body.GetLength(), file);
+		fclose(file);
+		body.ReleaseBuffer();
+	}
+	return (true);
+}
