@@ -399,11 +399,11 @@ BOOL CSummaryView::OnChildNotify(UINT message, WPARAM wParam, LPARAM lParam, LRE
 				RedrawUnreadCount();
 			}
 
+			tv->Update(m_path + "\\" + m_array_list[m_stack_num-m_index-1]->m_str5);
+
 			// mainframe̊e{^Lɂ
 			mf->UpdateButton2(TRUE);
 
-			tv->Update(m_path + "\\" + m_array_list[m_stack_num-m_index-1]->m_str5);
-
 			*pLResult = 0;
 		}
 	}
@@ -671,21 +671,27 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 				message.Format("Ytt@C\r\n%s", md.GetFileName(0));
 			}
 		}
-		app->m_me.AddText(message);
+		if (!md.IsPgpMime())
+			app->m_me.AddText(message);
 // --------------
 		int max = md.HowManyPart();	
+		int mainPart = md.GetMainTextPartNo();
 		int i;
 		for (i=0;i<max;++i) {
-			if (i==0 && (md.GetContentType(i).Find("text/plain")==0))
+			if (i==mainPart)
 				continue;
 
 			CString extension;
 			MULTIPART_STRUCT2 data;
 			data.m_file_name = md.GetFileName(i);
 //2005.11.29 moogv add
-//			data.m_content_type = md.GetContentType(i);		
-			data.m_content_type.Format("Content-Type: %s; name=\"%s\"", 
-										md.GetContentType(i), data.m_file_name);
+//			data.m_content_type = md.GetContentType(i);
+			if (md.IsPgpMime()) {
+				data.m_content_type.Format("Content-Type: %s;",md.GetContentType(i));
+			}else{
+				data.m_content_type.Format("Content-Type: %s; name=\"%s\"", 
+												md.GetContentType(i), data.m_file_name);
+			}
 //2005.11.29 moogv end		
 			data.m_content_transfer_encoding=md.GetRawCTE(i);
 
@@ -702,7 +708,6 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 			data.m_type = md.GetContentType(i);
 			app->m_me.AddMultipart(data);
 		}
-
 /*
 		MULTIPART_STRUCT2 data;
 		CString tmp = md.GetContentType(0);
