@@ -599,7 +599,15 @@ void CTextView::Update(LPCTSTR path)
 			this->Clear();
 			return;
 		}
-		DisplayPart(0); // anyway, 0st element of MULTIPARTSTRUCT is on display.
+//2005/12/03 moogv add start
+//		DisplayPart(0); // anyway, 0st element of MULTIPARTSTRUCT is on display.
+		int part = m_md.GetMainTextPartNo();
+		if (part >= 0) {
+			DisplayPart(part);
+		}else{
+			DisplayPart(0);
+		}
+//2005/12/03 moogv add end		
 
 		// pgp/mime or not
 		if(IsPgpMime()&&app->m_gpg_enable)
@@ -626,7 +634,7 @@ void CTextView::Update(LPCTSTR path)
 			}
 			mf->HideMultiPartView(FALSE);
 			// setting 0th item selected.
-			lc.SetItemState(0, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
+			//lc.SetItemState(0, LVIS_SELECTED | LVIS_FOCUSED, LVIS_SELECTED | LVIS_FOCUSED);
 		}
 		else if(!m_md.GetFileName(0).IsEmpty()){ // in case of only one attachment file.
 			CString enc_type;
